@@ -10,6 +10,9 @@ class SyncAPIResource:
     def __init__(self, client: "Ark") -> None:
         self._client = client
         self._post = client.post
+        self._get = client.get
+        self._delete = client.delete
+        self._post_without_retry = client.post_without_retry
 
 
 class AsyncAPIResource:
@@ -18,3 +21,6 @@ class AsyncAPIResource:
     def __init__(self, client: "AsyncArk") -> None:
         self._client = client
         self._post = client.post
+        self._get = client.get
+        self._delete = client.delete
+        self._post_without_retry = client.post_without_retry
