@@ -4,7 +4,8 @@ from .embedding_response import MultimodalEmbeddingResponse
 from .embedding_content_part_text_param import MultimodalEmbeddingContentPartTextParam
 from .embedding_content_part_image_param import MultimodalEmbeddingContentPartImageParam
 from .embedding_input import EmbeddingInputParam
-from .embedding_data import MultimodalEmbedding
+from .embedding_data import MultimodalEmbedding, SparseEmbedding
+from .sparse_embedding_input import SparseEmbeddingInput
 
 __all__ = [
     "MultimodalEmbeddingResponse",
@@ -12,4 +13,6 @@ __all__ = [
     "MultimodalEmbeddingContentPartImageParam",
     "EmbeddingInputParam",
     "MultimodalEmbedding",
+    "SparseEmbeddingInput",
+    "SparseEmbedding",
 ]
